Module: Evolvable::GeneCluster
- Defined in:
- lib/evolvable/gene_cluster.rb
Overview
Defined Under Namespace
Modules: ClassMethods
Class Method Summary collapse
-
.included(base) ⇒ void
When included in a class, extends the class with ClassMethods and initializes the cluster configuration.
Class Method Details
.included(base) ⇒ void
This method returns an undefined value.
When included in a class, extends the class with ClassMethods and initializes the cluster configuration. This is called automatically when you include the GeneCluster module in your class.
59 60 61 62 |
# File 'lib/evolvable/gene_cluster.rb', line 59 def self.included(base) base.extend(ClassMethods) base.instance_variable_set(:@cluster_config, []) end |